@@ -1,6 +1,6 @@
 /*
     common
-    copyright (c) 2002 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 2002-2003 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -22,10 +22,10 @@
 
 #ifdef HAVE_CONFIG_H
 # include "config.h"
-#endif
+#endif /* HAVE_CONFIG_H */
 #ifdef WIN32
 # include "config.w32.h"
-#endif
+#endif /* WIN32 */
 
 
 #include <stdio.h>
@@ -34,10 +34,25 @@
 # include <string.h>
 #elif HAVE_STRINGS_H
 # include <strings.h>
-#endif
+#endif /* HAVE_STRINGS_H */
 #include <gtk/gtk.h>
 
 
+#define SPACING 5
+
+
+#if defined USE_THREAD && ! defined G_THREADS_ENABLED
+# undef USE_THREAD
+#endif
+
+
+#ifdef G_HAVE_GINT64
+typedef gint64 goffset;
+#else /* not G_HAVE_GINT64 */
+typedef gint32 goffset;
+#endif /* not G_HAVE_GINT64 */
+
+
 #define g_strlen(s) ((s)!=NULL?strlen(s):0)
 #define g_strcmp(s1,s2) ((s1)!=NULL && (s2)!=NULL?strcmp(s1,s2):0)
 #define g_strncmp(s1,s2,n) ((s1)!=NULL && (s2)!=NULL?strncmp(s1,s2,n):0)
@@ -52,7 +67,7 @@
 # define g_strncpy(dest,src,dest_size) g_strlcpy(dest,src,dest_size)
 # define g_strncat(dest,src,dest_size) g_strlcat(dest,src,dest_size)
 # define g_strstr(haystack,needle) g_strstr_len(haystack,g_strlen(haystack),needle)
-#else
+#else /* USE_GTK2 */
 # include <stdarg.h>
 # define g_strcpy(dest,src) strcpy(dest,src)
 # define g_strcat(dest,src) strcat(dest,src)
@@ -61,10 +76,10 @@
 # ifdef HAVE_STRSTR
 #   define g_strstr(haystack,needle) strstr(haystack,needle)
 #   define g_strrstr(haystack,needle) strrstr(haystack,needle)
-# else
+# else /* not HAVE_STRSTR */
 #   define g_strstr(haystack,needle) NULL
 #   define g_strrstr(haystack,needle) NULL
-# endif 
+# endif /* not HAVE_STRSTR */
 # define g_snprintf snprintf
 # define g_vsnprintf vsnprintf
 # include <ctype.h>
@@ -82,7 +97,7 @@
 # define g_ascii_tolower(c) tolower(c)
 # define g_ascii_toupper(c) toupper(c)
 # define gtk_style_get_font(style) ((style)->font)
-#endif
+#endif /* not USE_GTK2 */
 
 
 #ifdef ENABLE_NLS
