@@ -18,15 +18,6 @@
 */
 #include "misc.h"
 #include <gdk/gdkkeysyms.h>
-#ifdef HAVE_SYS_STAT_H
-# include <sys/stat.h>
-#endif
-#ifdef HAVE_SYS_TYPES_H
-# include <sys/types.h>
-#endif
-#ifdef HAVE_UNISTD_H
-# include <unistd.h>
-#endif
 
 
 /******************************************************************************
@@ -35,20 +26,22 @@
 *                                                                             *
 ******************************************************************************/
 /* ܥ󤬲줿 */
-static void message_box_clicked(GtkWidget *widget,GtkWidget *dialog)
+static void
+message_box_clicked (GtkWidget *widget, GtkWidget *dialog)
 {
-	*(gint *)gtk_object_get_user_data(GTK_OBJECT(dialog))
-						=(gint)gtk_object_get_user_data(GTK_OBJECT(widget));
-    gtk_widget_destroy(dialog);
+	*(gint *)gtk_object_get_user_data (GTK_OBJECT (dialog))
+						= (gint)gtk_object_get_user_data (GTK_OBJECT (widget));
+    gtk_widget_destroy (dialog);
 }
 
 
 /* ESC줿 */
-static gboolean message_box_dialog_key_press(GtkWidget *widget,
-										GdkEventKey *event,gpointer user_data)
+static gboolean
+message_box_dialog_key_press (GtkWidget *widget,
+										GdkEventKey *event, gpointer user_data)
 {
-	if (event->keyval==GDK_Escape)
-		gtk_widget_destroy(widget);
+	if (event->keyval == GDK_Escape)
+		gtk_widget_destroy (widget);
 	return FALSE;
 }
 
@@ -59,56 +52,66 @@ static gboolean message_box_dialog_key_press(GtkWidget *widget,
 	  def,ǥեȤΥܥ
 	  ...,ܥΥ٥
 	  RET,줿ܥ(-1:󥻥)										*/
-gint misc_message_box(const gchar *title,const gchar *text,const gint def,...)
+gint
+misc_message_box (const gchar *title, const gchar *text, const gint def, ...)
 {
 	va_list ap;
 	gchar *name;
-	gint i=0,result=-1;
+	gint i = 0, result = -1;
 	guint key;
 	GtkAccelGroup *accel;
-	GtkWidget *dialog,*button,*label,*focus=NULL;
+	GtkWidget *dialog, *button, *label, *hbox0, *hbox1, *vbox, *focus = NULL;
 
-	va_start(ap,def);
-	/* 򳫤 */
-	dialog=gtk_dialog_new();
-	gtk_signal_connect_after(GTK_OBJECT(dialog),"key-press-event",
-						GTK_SIGNAL_FUNC(message_box_dialog_key_press),NULL);
-	gtk_signal_connect(GTK_OBJECT(dialog),"destroy",gtk_main_quit,NULL);
-	gtk_object_set_user_data(GTK_OBJECT(dialog),&result);
-	/* å */
-	gtk_window_set_title(GTK_WINDOW(dialog),title);
-	label=gtk_label_new(text);
-	gtk_misc_set_padding(GTK_MISC(label),8,8);
-	gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog)->vbox),label,TRUE,TRUE,0);
+	va_start (ap, def);
+	/* ᥤ󥦥ɥ */
+	dialog = gtk_window_new (GTK_WINDOW_TOPLEVEL);
+	gtk_window_set_title (GTK_WINDOW (dialog), title);
+	gtk_signal_connect_after (GTK_OBJECT (dialog), "key-press-event",
+						GTK_SIGNAL_FUNC (message_box_dialog_key_press), NULL);
+	gtk_signal_connect (GTK_OBJECT (dialog), "destroy", gtk_main_quit, NULL);
+	gtk_object_set_user_data (GTK_OBJECT (dialog), &result);
 	/* 졼 */
-	accel=gtk_accel_group_new();
-	gtk_window_add_accel_group(GTK_WINDOW(dialog),accel);
+	accel = gtk_accel_group_new ();
+	gtk_window_add_accel_group (GTK_WINDOW (dialog), accel);
+	/* ٥ */
+	label = gtk_label_new(text);
+	/* ܥå */
+	hbox0 = gtk_hbox_new (FALSE, SPACING);
 	/* ܥ */
-	gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (dialog)->action_area), 8);
-	while ((name=va_arg(ap,gchar *))!=NULL) {
-		button=gtk_button_new_with_label(name);
-		key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(button)->child),name);
-		gtk_signal_connect(GTK_OBJECT(button),"clicked",
-								GTK_SIGNAL_FUNC(message_box_clicked),dialog);
-		gtk_object_set_user_data(GTK_OBJECT(button),(gpointer)i);
-		GTK_WIDGET_SET_FLAGS(button,GTK_CAN_DEFAULT);
-		if (i==def)
-			focus=button;
-		if (key>0)/* 졼 */
-			gtk_widget_add_accelerator(button,"clicked",accel,key,0,0);
-		gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->action_area),
-													button, TRUE, FALSE, 0);
+	while ((name = va_arg (ap, gchar *)) != NULL)
+	  {
+		button = gtk_button_new_with_label (name);
+		key = gtk_label_parse_uline (GTK_LABEL (GTK_BIN (button)->child),
+																		name);
+		gtk_signal_connect (GTK_OBJECT (button), "clicked",
+								GTK_SIGNAL_FUNC (message_box_clicked), dialog);
+		gtk_object_set_user_data (GTK_OBJECT (button), (gpointer)i);
+		GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
+		if (i == def)
+			focus = button;
+		if (key > 0)/* 졼 */
+			gtk_widget_add_accelerator (button, "clicked", accel, key, 0, 0);
+		gtk_box_pack_start (GTK_BOX (hbox0), button, FALSE, FALSE, 0);
 		i++;
-	}
-	va_end(ap);
+	  }
+	va_end (ap);
+
+	/* ܥå */
+	vbox = gtk_vbox_new (FALSE, SPACING);
+	gtk_container_set_border_width (GTK_CONTAINER (vbox), SPACING);
+	gtk_box_pack_start (GTK_BOX (vbox), label, TRUE, TRUE, 0);
+	hbox1 = gtk_hbox_new (FALSE, 0);
+	gtk_box_pack_end (GTK_BOX (hbox1), hbox0, TRUE, FALSE, 0);
+	gtk_box_pack_end (GTK_BOX (vbox), hbox1, FALSE, FALSE, 0);
+	gtk_container_add (GTK_CONTAINER (dialog), vbox);
 
 	/* ɽ */
-	if (focus!=NULL)
-		gtk_widget_grab_focus(focus);
+	if (focus != NULL)
+		gtk_widget_grab_focus (focus);
 
-	gtk_grab_add(dialog);
-	gtk_widget_show_all(dialog);
-	gtk_main();
+	gtk_grab_add (dialog);
+	gtk_widget_show_all (dialog);
+	gtk_main ();
 
 	return result;
 }
@@ -119,73 +122,6 @@ gint misc_message_box(const gchar *title,const gchar *text,const gint def,...)
 * ٥ؿ                                                              *
 *                                                                             *
 ******************************************************************************/
-/*	ե¸߳ǧ
-	file,ե̾
-	 RET,TRUE:¸ߤ,FALSE:¸ߤʤ										*/
-gboolean misc_isfile(const gchar *file)
-{
-	struct stat buf;
-
-	return stat(file,&buf)==0;
-}
-
-
-/*	եΥեѥ
-	file,ե̾
-	 RET,եѥ															*/
-gchar *misc_get_full_path(const gchar *file)
-{
-	gchar *dir,*path;
-	gint i,j,leng;
-
-	if (file[0]!='/') {
-		dir=g_get_current_dir();
-		path=g_strjoin("/",dir,file,NULL);
-		g_free(dir);
-	} else {
-		path=g_strdup(file);
-	}
-	leng=g_strlen(path);
-	i = 0;
-	while (i < leng)
-		if (path[i] == '/' && path[i + 1] == '/')
-		  {
-			leng--;
-			g_memmove (path + i + 1, path + i + 2, leng - i);
-		  }
-		else
-		  {
-			i++;
-		  }
-	i=0;
-	while (i<leng)
-		if (path[i]=='/' && path[i+1]=='.' && path[i+2]=='/') {
-			leng-=2;
-			g_memmove(path+i+1,path+i+3,leng-i);
-		} else {
-			i++;
-		}
-	i=0;
-	while (i<leng)
-		if (path[i]=='/' && path[i+1]=='.' && path[i+2]=='.'
-														&& path[i+3]=='/') {
-			leng-=3;
-			g_memmove(path+i+1,path+i+4,leng-i);
-			for (j=i-1;j>=0;j--)
-				if (path[j]=='/')
-					break;
-			if (j>=0) {
-				g_memmove(path+j+1,path+i+1,leng-i);
-				leng-=i-j;
-				i=j;
-			}
-		} else {
-			i++;
-		}
-	return path;
-}
-
-
 /*	Сꤹ
 	   scroll,륦å
 	     func,ʥؿ
@@ -262,8 +198,8 @@ void misc_scroll_window(GtkWidget *widget,const gint dx,const gint dy,
 * ʸؿ                                                            *
 *                                                                             *
 ******************************************************************************/
-static gchar hex[16]={	'0','1','2','3','4','5','6','7',
-						'8','9','A','B','C','D','E','F'};
+const static gchar hex[16]={'0', '1', '2', '3', '4', '5', '6', '7',
+							'8', '9', 'A', 'B', 'C', 'D', 'E', 'F'};
 
 
 /*	͢ʸ
@@ -396,7 +332,11 @@ gchar *misc_str_from_float(const gint value,const gint divide)
 	gchar *text=NULL;
 	gint i=0,n,t;
 
+#ifdef G_HAVE_GINT64
 	n=t=(gint64)value*100000/divide;
+#else /* not G_HAVE_GINT64 */
+	n = t = value * 100000 / divide;
+#endif /* not G_HAVE_GINT64 */
 	if (t==0) {
 		text=g_malloc(sizeof(gchar)*4);
 		text[i++]=hex[0];
