@@ -17,7 +17,6 @@
     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 #include "argument.h"
-#include "charset.h"
 #include "misc/misc.h"
 
 
@@ -44,7 +43,6 @@ gboolean *arg_analyse(gchar **argv,const gboolean boot)
 		const char *arg;
 		const char *doc;
 	} arg_opts[]={
-	{"encoding",'c',"CHARSET",     N_("Character Encoding")},
 	{"history", 'h',"NUM",         N_("History")},
 	{"line",    'l',"NUM",         N_("Caret Position")},
 	{"new",     'n',"ON/OFF",      N_("New File")},
@@ -93,10 +91,6 @@ gboolean *arg_analyse(gchar **argv,const gboolean boot)
 						break;
 					}
 				switch (opt) {
-					case 'c':
-						if (boot)
-							charset_set(arg);
-						break;
 					case 'h':
 						misc_str_to_val(&history,arg,10,TRUE);
 						if (history<0)
