@@ -589,11 +589,11 @@ charlist_dialog (gchar *charlist)
 	g_signal_connect_swapped (G_OBJECT (button5), "clicked",
 						G_CALLBACK (gtk_widget_destroy), G_OBJECT (dialog));
 	/* ܥå */
-	vbox = gtk_vbox_new (FALSE, 8);
-	gtk_container_set_border_width (GTK_CONTAINER (vbox), 8);
+	vbox = gtk_vbox_new (FALSE, SPACING);
+	gtk_container_set_border_width (GTK_CONTAINER (vbox), SPACING);
 	gtk_box_pack_start (GTK_BOX (vbox), scroll, TRUE, TRUE, 0);
 	gtk_box_pack_start (GTK_BOX (vbox), combo, FALSE, FALSE, 0);
-	hbox = gtk_hbox_new (FALSE, 8);
+	hbox = gtk_hbox_new (FALSE, SPACING);
 	gtk_box_pack_start (GTK_BOX (hbox), button0, FALSE, FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (hbox), button1, FALSE, FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (hbox), button2, FALSE, FALSE, 0);
