@@ -244,9 +244,16 @@ gint edit_get_screen_pos(TmaidWindow *tmaid,const gint x,const gint y)
 	  text,ʸ
 	length,ʸ
 	   RET,ʬ																*/
-guint edit_get_char_type(const gchar *text,const gint length)
+guint
+edit_get_char_type (const gchar *text, const gsize length)
 {
-	return charset_type (text, length);
+	guint ct;
+
+	if (length < charset_length (*text))
+		return 0;
+	ct = charset_type (text);
+	return  ct != CS_CONTROL && ct != CS_SPACE && ct != CS_PUNCT
+								&& ct != CS_SYMBOL && ct != CS_ACCENT ? ct : 0;
 }
 
 
@@ -275,11 +282,12 @@ gint edit_get_move_pos(TmaidWindow *tmaid,const gint x,const gint y,
 			length=data_pos+charset_length(p->text[data_pos])<=p->length
 										?charset_length(p->text[data_pos]):1;
 			ct=edit_get_char_type(p->text+data_pos,length);
-			if ((ctype&ct)==0) {
+			if (ctype != ct)
+			  {
 				if (ct!=0)
 					break;
 				ctype=0;
-			}
+			  }
 			data_pos+=length;
 		}
 	} else {
@@ -302,13 +310,14 @@ gint edit_get_move_pos(TmaidWindow *tmaid,const gint x,const gint y,
 		ctype=edit_get_char_type(p->text+data_pos,length);
 		while (data_pos>0 && (data_pos-=length=type[data_pos-1])>=0) {
 			ct=edit_get_char_type(p->text+data_pos,length);
-			if ((ctype&ct)==0) {
+			if (ctype != ct)
+			  {
 				if (ctype!=0) {
 					data_pos+=length;
 					break;
 				}
 				ctype=ct;
-			}
+			  }
 		}
 		g_free(type);
 	}
