@@ -268,10 +268,10 @@ void format_dialog(void)
 	GTK_WIDGET_SET_FLAGS(button4,GTK_CAN_DEFAULT);
 	GTK_WIDGET_SET_FLAGS(button5,GTK_CAN_DEFAULT);
 	/* ܥå */
-	vbox=gtk_vbox_new(FALSE,8);
-	gtk_container_set_border_width(GTK_CONTAINER(vbox),8);
+	vbox = gtk_vbox_new (FALSE, SPACING);
+	gtk_container_set_border_width (GTK_CONTAINER (vbox), SPACING);
 	gtk_box_pack_start(GTK_BOX(vbox),scroll,TRUE,TRUE,0);
-	hbox=gtk_hbox_new(FALSE,8);
+	hbox = gtk_hbox_new (FALSE, SPACING);
 	gtk_box_pack_start(GTK_BOX(hbox),button0,FALSE,FALSE,0);
 	gtk_box_pack_start(GTK_BOX(hbox),button1,FALSE,FALSE,0);
 	gtk_box_pack_start(GTK_BOX(hbox),button2,FALSE,FALSE,0);
