@@ -57,10 +57,12 @@ void hide_caret(TmaidWindow *tmaid)
 	cursor,ŤåȰ												*/
 void draw_caret(TmaidWindow *tmaid,GdkPoint *cursor)
 {
+	gboolean visible;
 	gchar *text;
 	gint x,y;
 	guint context_id;
 	GdkRectangle rc;
+	GtkWidget *widget;
 
 	if (cursor!=NULL && timer_id!=0
 			&& (tmaid->cursor.x!=cursor->x || tmaid->cursor.y!=cursor->y)) {
@@ -100,8 +102,18 @@ void draw_caret(TmaidWindow *tmaid,GdkPoint *cursor)
 	gtk_statusbar_push(GTK_STATUSBAR(status),context_id,text);
 	g_free(text);
 	gdk_window_get_origin (tmaid->drawing->window, &x, &y);
-	gtk_window_move (GTK_WINDOW (gtk_widget_get_parent (tmaid->preedit)),
-														rc.x + x, rc.y + y);
+	widget = gtk_widget_get_parent (tmaid->preedit);
+	visible = GTK_WIDGET_VISIBLE (widget);
+	if (!visible)
+	  {
+		gtk_window_resize (GTK_WINDOW (widget), 1, 1);
+		gtk_widget_show (widget);
+	  }
+	gtk_window_move (GTK_WINDOW (widget), rc.x + x, rc.y + y);
+	if (!visible)
+		gtk_widget_hide (widget);
+	rc.width = 0;
+	gtk_im_context_set_cursor_location (tmaid->im_context, &rc);
 }
 
 
@@ -156,6 +168,9 @@ void set_menu_bar(TmaidWindow *tmaid)
 		gtk_widget_set_sensitive(toolbar_items[14].item,tmaid->redo!=NULL);
 		gtk_widget_set_sensitive(toolbar_items[16].item,TRUE);
 		gtk_widget_set_sensitive(toolbar_items[17].item,TRUE);
+#ifdef G_OS_WIN32
+		gtk_widget_set_sensitive (toolbar_items[19].item, TRUE);
+#endif /* G_OS_WIN32 */
 	} else {
 		gtk_widget_set_sensitive(gtk_menu_get_attach_widget(GTK_MENU(
 								gtk_item_factory_get_widget(item_factory_menu,
@@ -186,6 +201,9 @@ void set_menu_bar(TmaidWindow *tmaid)
 		gtk_widget_set_sensitive(toolbar_items[14].item,FALSE);
 		gtk_widget_set_sensitive(toolbar_items[16].item,FALSE);
 		gtk_widget_set_sensitive(toolbar_items[17].item,FALSE);
+#ifdef G_OS_WIN32
+		gtk_widget_set_sensitive (toolbar_items[19].item, FALSE);
+#endif /* G_OS_WIN32 */
 	}
 	menu=gtk_item_factory_get_widget(item_factory_menu,"<main>/Window");
 	glist=gtk_container_children(GTK_CONTAINER(menu));
