@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2002 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2003 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -76,6 +76,13 @@ void modify_margin(TmaidWindow *tmaid);
 gboolean prompt_close(TmaidWindow *tmaid);
 
 
+/*	֤ԽѤߥޡѹ
+	  tmaid,ɥ
+	is_edit,TRUE:ԽѤ,FALSE:̤Խ										*/
+void
+tmaid_change_edit(TmaidWindow *tmaid,gboolean is_edit);
+
+
 /*	Խ
 	tmaid,TXTɥ
 	 kind,TRUE:redo,FALSE:undo												*/
