@@ -186,11 +186,11 @@ reload_dialog (FileType *ft, const gchar *text)
 	for (i = g_list_length (glist) - 1; i >= 0; i--)
 		g_free (g_list_nth_data (glist, i));
 	/* ե졼ȥܥå */
-	hbox = gtk_hbox_new (FALSE, 8);
+	hbox = gtk_hbox_new (FALSE, SPACING);
 	gtk_box_pack_end (GTK_BOX (hbox), button1, FALSE, FALSE, 0);
 	gtk_box_pack_end (GTK_BOX (hbox), button0, FALSE, FALSE, 0);
-	vbox = gtk_vbox_new (FALSE, 8);
-	gtk_container_set_border_width (GTK_CONTAINER (vbox), 8);
+	vbox = gtk_vbox_new (FALSE, SPACING);
+	gtk_container_set_border_width (GTK_CONTAINER (vbox), SPACING);
 	if (text != NULL)
 		gtk_box_pack_start (GTK_BOX (vbox),
 										gtk_label_new (text), FALSE, FALSE, 0);
