@@ -94,19 +94,21 @@ gint repinfo_dialog(ReplaceInfo *ri)
 	GTK_WIDGET_SET_FLAGS(button2,GTK_CAN_DEFAULT);
 	GTK_WIDGET_SET_FLAGS(button3,GTK_CAN_DEFAULT);
 	/* ե졼ȥܥå */
-	tbox=gtk_vbox_new(FALSE,8);
-	gtk_container_set_border_width(GTK_CONTAINER(tbox),8);
-	hbox=gtk_hbox_new(FALSE,8);
+	tbox = gtk_vbox_new (FALSE, SPACING);
+	gtk_container_set_border_width (GTK_CONTAINER (tbox), SPACING);
+	hbox = gtk_hbox_new (FALSE, SPACING);
 	gtk_box_pack_start(GTK_BOX(hbox),
 								gtk_label_new(_("Find String")),FALSE,FALSE,0);
-	gtk_box_pack_start(GTK_BOX(hbox),gtk_label_new(ri->src),TRUE,TRUE,0);
+	gtk_box_pack_start (GTK_BOX (hbox),
+				gtk_label_new (ri->src != NULL ? ri->src : ""), TRUE, TRUE, 0);
 	gtk_box_pack_start(GTK_BOX(tbox),hbox,FALSE,FALSE,0);
-	hbox=gtk_hbox_new(FALSE,8);
+	hbox = gtk_hbox_new (FALSE, SPACING);
 	gtk_box_pack_start(GTK_BOX(hbox),
 							gtk_label_new(_("Replace String")),FALSE,FALSE,0);
-	gtk_box_pack_start(GTK_BOX(hbox),gtk_label_new(ri->dst),TRUE,TRUE,0);
+	gtk_box_pack_start (GTK_BOX (hbox),
+				gtk_label_new (ri->dst != NULL ? ri->dst : ""), TRUE, TRUE, 0);
 	gtk_box_pack_start(GTK_BOX(tbox),hbox,FALSE,FALSE,0);
-	hbox=gtk_hbox_new(FALSE,8);
+	hbox = gtk_hbox_new (FALSE, SPACING);
 	gtk_box_pack_start(GTK_BOX(hbox),
 							gtk_label_new(_("Replace Range")),FALSE,FALSE,0);
 	text=g_strdup_printf(_("(%d,%d)-(%d,%d)"),
@@ -116,24 +118,24 @@ gint repinfo_dialog(ReplaceInfo *ri)
 	gtk_box_pack_start(GTK_BOX(tbox),hbox,FALSE,FALSE,0);
 
 	frame0=gtk_frame_new(_("Option"));
-	vbox=gtk_vbox_new(FALSE,8);
-	gtk_container_set_border_width(GTK_CONTAINER(vbox),8);
+	vbox = gtk_vbox_new (FALSE, SPACING);
+	gtk_container_set_border_width (GTK_CONTAINER (vbox), SPACING);
 	gtk_box_pack_start(GTK_BOX(vbox),gtk_label_new(ri->ignorecase
 							?_("Enable Case"):_("Ignore Case")),FALSE,FALSE,0);
 	gtk_container_add(GTK_CONTAINER(frame0),vbox);
 
 	frame1=gtk_frame_new(_("Direction"));
-	vbox=gtk_vbox_new(FALSE,8);
-	gtk_container_set_border_width(GTK_CONTAINER(vbox),8);
+	vbox = gtk_vbox_new (FALSE, SPACING);
+	gtk_container_set_border_width (GTK_CONTAINER (vbox), SPACING);
 	gtk_box_pack_start(GTK_BOX(vbox),
 					gtk_label_new(ri->arrow?_("Up"):_("Down")),FALSE,FALSE,0);
 	gtk_container_add(GTK_CONTAINER(frame1),vbox);
 
-	hbox=gtk_hbox_new(FALSE,8);
+	hbox = gtk_hbox_new (FALSE, SPACING);
 	gtk_box_pack_start(GTK_BOX(hbox),frame0,TRUE,TRUE,0);
 	gtk_box_pack_start(GTK_BOX(hbox),frame1,TRUE,TRUE,0);
 	gtk_box_pack_start(GTK_BOX(tbox),hbox,TRUE,TRUE,0);
-	hbox=gtk_hbox_new(FALSE,8);
+	hbox = gtk_hbox_new (FALSE, SPACING);
 	gtk_box_pack_end(GTK_BOX(hbox),button3,FALSE,FALSE,0);
 	gtk_box_pack_end(GTK_BOX(hbox),button2,FALSE,FALSE,0);
 	gtk_box_pack_end(GTK_BOX(hbox),button1,FALSE,FALSE,0);
