@@ -59,7 +59,15 @@ gboolean signal_timeout(gpointer data)
 gboolean signal_focus_in(GtkWidget *widget,
 									GdkEventFocus *event,TmaidWindow *tmaid)
 {
+	gchar *str;
+
 	GTK_WIDGET_SET_FLAGS(widget,GTK_HAS_FOCUS);
+	gtk_im_context_get_preedit_string (tmaid->im_context, &str, NULL, NULL);
+	if (g_strlen (str) > 0)
+		gtk_widget_show (gtk_widget_get_parent (tmaid->preedit));
+	else
+		gtk_widget_hide (gtk_widget_get_parent (tmaid->preedit));
+	g_free (str);
 	gtk_im_context_focus_in (tmaid->im_context);
 	draw_caret(tmaid,NULL);
 	return FALSE;
@@ -70,6 +78,7 @@ gboolean signal_focus_out(GtkWidget *widget,
 									GdkEventFocus *event,TmaidWindow *tmaid)
 {
 	GTK_WIDGET_UNSET_FLAGS(widget,GTK_HAS_FOCUS);
+	gtk_widget_hide (gtk_widget_get_parent (tmaid->preedit));
 	gtk_im_context_focus_out (tmaid->im_context);
 	draw_caret(tmaid,NULL);
 	return FALSE;
@@ -203,6 +212,7 @@ void signal_destroy_draw(GtkWidget *widget,TmaidWindow *tmaid)
 void
 signal_commit (GtkIMContext *im_context, gchar *arg1, TmaidWindow *tmaid)
 {
+	gchar *str;
 	gint i, leng, length;
 	TmaidHistory *d;
 	GdkPoint select;
@@ -235,6 +245,9 @@ signal_commit (GtkIMContext *im_context, gchar *arg1, TmaidWindow *tmaid)
 			set_menu_bar (tmaid);
 		tmaid_change_edit (tmaid, TRUE);
 	  }
+	gtk_im_context_get_preedit_string (im_context, &str, NULL, NULL);
+	if (g_strlen (str) <= 0)
+		gtk_widget_hide (gtk_widget_get_parent (tmaid->preedit));
 }
 
 
@@ -293,12 +306,10 @@ signal_expose_preedit (GtkWidget *widget,
 									GdkEventExpose *event, TmaidWindow *tmaid)
 {
 	gchar *str;
-	gint cursor_pos;
 	GdkGC *gc;
 	PangoAttrList *attrs;
 
-	gtk_im_context_get_preedit_string (tmaid->im_context,
-													&str, &attrs, &cursor_pos);
+	gtk_im_context_get_preedit_string (tmaid->im_context, &str, &attrs, NULL);
 	pango_layout_set_text (tmaid->layout, str, -1);
 	g_free (str);
 	pango_layout_set_attributes (tmaid->layout, attrs);
@@ -648,7 +659,7 @@ gboolean signal_button_press(GtkWidget *widget,
 			{
 				gchar *text=NULL;
 				gint length;
-				GdkPoint cursor,select;
+				GdkPoint select;
 				TmaidHistory *d;
 
 				if (gdk_selection_owner_get(GDK_SELECTION_PRIMARY)
@@ -661,27 +672,16 @@ gboolean signal_button_press(GtkWidget *widget,
 					edit_cpy_sel_mem(tmaid,&tmaid->select,&tmaid->cursor,text);
 					text[length]='\0';
 				}
-				/* åȰư */
-				cursor=tmaid->cursor;
-				select=tmaid->select;
-				tmaid->cursor.x=tmaid->top.x+event->x/tmaid->font_width;
-				tmaid->cursor.y=tmaid->top.y+event->y/tmaid->font_height;
-				if (tmaid->cursor.y<0)
-					tmaid->cursor.y=0;
-				else if (tmaid->cursor.y>tmaid->max-1)
-					tmaid->cursor.y=tmaid->max-1;
-				if (tmaid->cursor.x<edit_get_width(tmaid,tmaid->cursor.y))
-					tmaid->cursor.x=edit_get_align_pos(tmaid,
-										tmaid->cursor.x,tmaid->cursor.y,FALSE);
 				/*  */
 				if (tmaid->select.x>=0) {
+					select=tmaid->select;
 					tmaid->select.x=-1;
-					clear_sel(tmaid,&cursor,&select);
+					clear_sel (tmaid, &tmaid->cursor, &select);
 					if (text==NULL)
 						set_menu_bar(tmaid);
 				}
 				/* å */
-				draw_caret(tmaid,&cursor);
+				draw_caret (tmaid, &tmaid->cursor);
 				if (text!=NULL) {
 					/* Žդ */
 					d=edit_operation(tmaid,text,g_strlen(text),FALSE,TRUE);
@@ -765,13 +765,14 @@ gboolean signal_button_press(GtkWidget *widget,
 					i-=length;
 					ctype=edit_get_char_type(p->text+i,length);
 				}
-				while (i>0 && (i-=(length=type[i-1]))>0) {
+				while (i > 0 && (i -= (length = type[i - 1])) >= 0)
+				  {
 					ct=edit_get_char_type(p->text+i,length);
 					if (ctype!=ct) {
 						i+=length;
 						break;
 					}
-				}
+				  }
 				g_free(type);
 			} else {
 				length=charset_length(p->text[0])<=p->length
