@@ -155,28 +155,36 @@ void signal_destroy_notebook(GtkWidget *widget,gpointer user_data)
 * ʥ/٥ȴؿ(쥯)                                       *
 *                                                                             *
 ******************************************************************************/
-void signal_drag_data_received(GtkWidget *widget,GdkDragContext *context,
-		gint x,gint y,GtkSelectionData *selection_data,guint info,guint time)
+void
+signal_drag_data_received (GtkWidget *widget, GdkDragContext *context,
+	gint x, gint y, GtkSelectionData *selection_data, guint info, guint time)
 {
-	gchar **files;
+	gchar *file, **files;
 	gint i;
 
-	files=g_strsplit(selection_data->data,"\r\n",G_MAXINT);
-	for (i=0;files[i]!=NULL;i++)
-		if (g_strncmp(files[i],"file:",5)==0)
-			file_open_edit(files[i]+5);
-	g_strfreev(files);
+	files = g_strsplit (selection_data->data, "\r\n", G_MAXINT);
+	for (i = 0; files[i] != NULL; i++)
+	  {
+		file = g_filename_from_uri (files[i], NULL, NULL);
+		if (file != NULL)
+		  {
+			file_open_edit (file);
+			g_free (file);
+		  }
+	  }
+	g_strfreev (files);
 }
 
 
 gboolean signal_selection_clear(GtkWidget *widget,GdkEventSelection *event,
 															gpointer user_data)
 {
-	if (event->selection==atom_clipboard) {
+	if (event->selection == GDK_SELECTION_CLIPBOARD)
+	  {
 		/* åץܡ */
-		g_free(clipboard_text);
-		clipboard_text=NULL;
-	}
+		g_free (clipboard_text);
+		clipboard_text = NULL;
+	  }
 	return TRUE;
 }
 
@@ -195,7 +203,7 @@ void signal_selection_get(GtkWidget *widget,GtkSelectionData *data,
 			edit_cpy_sel_mem(tmaid,&tmaid->select,&tmaid->cursor,text);
 			text[length]='\0';
 		}
-	} else if (data->selection==atom_clipboard) {
+	} else if (data->selection == GDK_SELECTION_CLIPBOARD) {
 		/* åץܡ */
 		if (clipboard_text!=NULL) {
 			text=clipboard_text;
@@ -233,8 +241,8 @@ void signal_selection_received(GtkWidget *widget,GtkSelectionData *data,
 	GdkAtom *atoms;
 	GdkPoint select;
 
-	if (data->selection==GDK_SELECTION_PRIMARY
-										|| data->selection==atom_clipboard) {
+	if (data->selection == GDK_SELECTION_PRIMARY
+							|| data->selection == GDK_SELECTION_CLIPBOARD) {
 		/* ץ饤ޥꥻ쥯/åץܡ */
 		if (data->length>=0) {
 			if (data->type==GDK_SELECTION_TYPE_ATOM) {
@@ -264,8 +272,8 @@ void signal_selection_received(GtkWidget *widget,GtkSelectionData *data,
 					gtk_notebook_get_current_page (GTK_NOTEBOOK (notebook)))),
 																"user_data");
 			select=tmaid->select;
-			d=edit_operation(tmaid,text,g_strlen(text),
-										data->selection==atom_clipboard,FALSE);
+			d = edit_operation (tmaid, text, g_strlen (text),
+							data->selection == GDK_SELECTION_CLIPBOARD, FALSE);
 			d->next=tmaid->undo;
 			tmaid->undo=d;
 			if (delete_list(&tmaid->redo)>0 || d->next==NULL || select.x>=0)
