@@ -351,6 +351,30 @@ static gchar *tb_replace_xpm[]={
 "       ,        "};
 
 
+#ifdef G_OS_WIN32
+/* XPM */
+static gchar *tb_close_xpm[]={
+"16 16 2 1",
+" 	c None",
+".	c #000000",
+"                ",
+"                ",
+"   ..      ..   ",
+"    ..    ..    ",
+"     ..  ..     ",
+"      ....      ",
+"       ..       ",
+"       ..       ",
+"      ....      ",
+"     ..  ..     ",
+"    ..    ..    ",
+"   ..      ..   ",
+"                ",
+"                ",
+"                "};
+#endif /* G_OS_WIN32 */
+
+
 ToolBar toolbar_items[]={
 /*  0 */ {N_("New"),       tb_new_xpm,    command_new,     NULL,NULL},
 /*  1 */ {N_("Open"),      tb_open_xpm,   command_open,    NULL,NULL},
@@ -370,4 +394,8 @@ ToolBar toolbar_items[]={
 /* 15 */ {NULL,            NULL,          NULL,            NULL,NULL},
 /* 16 */ {N_("Find"),      tb_find_xpm,   command_find,    NULL,NULL},
 /* 17 */ {N_("Replace"),   tb_replace_xpm,command_replace, NULL,NULL},
-/* 18 */ {(gpointer)-1,    NULL,          NULL,            NULL,NULL}};
+#ifdef G_OS_WIN32
+/* 18 */ {NULL,            NULL,          NULL,            NULL,NULL},
+/* 19 */ {N_("Close"),     tb_close_xpm,  command_close,   NULL,NULL},
+#endif /* G_OS_WIN32 */
+/*    */ {(gpointer)-1,    NULL,          NULL,            NULL,NULL}};
